@@ -16,35 +16,40 @@ CREATE FUNCTION pgroonga_score("row" record)
 	AS 'MODULE_PATHNAME', 'pgroonga_score_row'
 	LANGUAGE C
 	VOLATILE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_score(tableoid oid, ctid tid)
 	RETURNS float8
 	AS 'MODULE_PATHNAME', 'pgroonga_score_ctid'
 	LANGUAGE C
 	VOLATILE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_table_name(indexName cstring)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_table_name'
 	LANGUAGE C
 	STABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_command(groongaCommand text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_command'
 	LANGUAGE C
 	VOLATILE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_command(groongaCommand text, arguments text[])
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_command'
 	LANGUAGE C
 	VOLATILE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_query_expand(tableName cstring,
 				      termColumnName text,
@@ -54,21 +59,24 @@ CREATE FUNCTION pgroonga_query_expand(tableName cstring,
 	AS 'MODULE_PATHNAME', 'pgroonga_query_expand'
 	LANGUAGE C
 	STABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_snippet_html(target text, keywords text[])
 	RETURNS text[]
 	AS 'MODULE_PATHNAME', 'pgroonga_snippet_html'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_highlight_html(target text, keywords text[])
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_highlight_html(target text,
 				        keywords text[],
@@ -77,119 +85,156 @@ CREATE FUNCTION pgroonga_highlight_html(target text,
 	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_positions_byte(target text, keywords text[])
 	RETURNS integer[2][]
 	AS 'MODULE_PATHNAME', 'pgroonga_match_positions_byte'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_match_positions_byte(target text,
+					      keywords text[],
+					      indexName cstring)
+	RETURNS integer[2][]
+	AS 'MODULE_PATHNAME', 'pgroonga_match_positions_byte'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_positions_character(target text, keywords text[])
 	RETURNS integer[2][]
 	AS 'MODULE_PATHNAME', 'pgroonga_match_positions_character'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_match_positions_character(target text,
+						   keywords text[],
+						   indexName cstring)
+	RETURNS integer[2][]
+	AS 'MODULE_PATHNAME', 'pgroonga_match_positions_character'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_query_extract_keywords(query text)
 	RETURNS text[]
 	AS 'MODULE_PATHNAME', 'pgroonga_query_extract_keywords'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_flush(indexName cstring)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_flush'
 	LANGUAGE C
 	VOLATILE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_command_escape_value(value text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_command_escape_value'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_query_escape(query text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_query_escape'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_string'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value text, special_characters text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_string'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value boolean)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_boolean'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value int2)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_int2'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value int4)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_int4'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value int8)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_int8'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value float4)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_float4'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value float8)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_float8'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value timestamp)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_timestamptz'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_escape(value timestamptz)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_escape_timestamptz'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_wal_apply()
 	RETURNS bigint
@@ -224,7 +269,8 @@ CREATE FUNCTION pgroonga_is_writable()
 	AS 'MODULE_PATHNAME', 'pgroonga_is_writable'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_set_writable(newWritable bool)
 	RETURNS bool
@@ -238,21 +284,24 @@ CREATE FUNCTION pgroonga_normalize(target text)
 	AS 'MODULE_PATHNAME', 'pgroonga_normalize'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_normalize(target text, normalizerName text)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_normalize'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_tokenize(target text, VARIADIC options text[])
 	RETURNS json[]
 	AS 'MODULE_PATHNAME', 'pgroonga_tokenize'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_vacuum()
 	RETURNS bool
@@ -266,14 +315,32 @@ CREATE FUNCTION pgroonga_index_column_name(indexName cstring, columnName text)
 	AS 'MODULE_PATHNAME', 'pgroonga_index_column_name_name'
 	LANGUAGE C
 	STABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_index_column_name(indexName cstring, columnIndex int4)
 	RETURNS text
 	AS 'MODULE_PATHNAME', 'pgroonga_index_column_name_index'
 	LANGUAGE C
 	STABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_result_to_recordset(result jsonb)
+	RETURNS SETOF RECORD
+	AS 'MODULE_PATHNAME', 'pgroonga_result_to_recordset'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_result_to_jsonb_objects(result jsonb)
+	RETURNS jsonb
+	AS 'MODULE_PATHNAME', 'pgroonga_result_to_jsonb_objects'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
 
 
 /* v1 */
@@ -282,28 +349,32 @@ CREATE FUNCTION pgroonga_match_term(target text, term text)
 	AS 'MODULE_PATHNAME', 'pgroonga_match_term_text'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_term(target text[], term text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_term_text_array'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_term(target varchar, term varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_term_varchar'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_term(target varchar[], term varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_term_varchar_array'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE OPERATOR %% (
 	PROCEDURE = pgroonga_match_term,
@@ -343,21 +414,24 @@ CREATE FUNCTION pgroonga_match_query(text, text)
 	AS 'MODULE_PATHNAME', 'pgroonga_match_query_text'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_query(text[], text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_query_text_array'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_query(varchar, varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_query_varchar'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE OPERATOR @@ (
 	PROCEDURE = pgroonga_match_query,
@@ -389,14 +463,16 @@ CREATE FUNCTION pgroonga_match_regexp(text, text)
 	AS 'MODULE_PATHNAME', 'pgroonga_match_regexp_text'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE FUNCTION pgroonga_match_regexp(varchar, varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_regexp_varchar'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE OPERATOR @~ (
 	PROCEDURE = pgroonga_match_regexp,
@@ -422,6 +498,7 @@ CREATE FUNCTION pgroonga_match_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -439,6 +516,7 @@ CREATE FUNCTION pgroonga_match_text_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -457,6 +535,7 @@ CREATE FUNCTION pgroonga_match_text_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -473,6 +552,7 @@ CREATE FUNCTION pgroonga_match_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -490,6 +570,7 @@ CREATE FUNCTION pgroonga_match_text_array_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -508,6 +589,7 @@ CREATE FUNCTION pgroonga_match_text_array_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -524,6 +606,7 @@ CREATE FUNCTION pgroonga_match_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -541,6 +624,7 @@ CREATE FUNCTION pgroonga_match_varchar_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -559,6 +643,7 @@ CREATE FUNCTION pgroonga_match_varchar_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -575,6 +660,7 @@ CREATE FUNCTION pgroonga_contain_varchar_array(varchar[], varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &> (
@@ -591,6 +677,7 @@ CREATE FUNCTION pgroonga_match_jsonb(jsonb, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@ (
@@ -607,6 +694,7 @@ CREATE FUNCTION pgroonga_query_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -633,6 +721,7 @@ CREATE FUNCTION pgroonga_query_text_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -651,6 +740,7 @@ CREATE FUNCTION pgroonga_query_text_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -667,6 +757,7 @@ CREATE FUNCTION pgroonga_query_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -693,6 +784,7 @@ CREATE FUNCTION pgroonga_query_text_array_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -711,6 +803,7 @@ CREATE FUNCTION pgroonga_query_text_array_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -727,6 +820,7 @@ CREATE FUNCTION pgroonga_query_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -753,6 +847,7 @@ CREATE FUNCTION pgroonga_query_varchar_condition
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -771,6 +866,7 @@ CREATE FUNCTION pgroonga_query_varchar_condition_with_scorers
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@~ (
@@ -787,6 +883,7 @@ CREATE FUNCTION pgroonga_query_jsonb(jsonb, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -812,7 +909,8 @@ CREATE FUNCTION pgroonga_similar_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
-	COST 300;
+	PARALLEL SAFE
+	COST 10000;
 
 -- Deprecated since 1.2.2.
 CREATE OPERATOR &~? (
@@ -837,7 +935,8 @@ CREATE FUNCTION pgroonga_similar_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
-	COST 300;
+	PARALLEL SAFE
+	COST 10000;
 
 -- Deprecated since 1.2.2.
 CREATE OPERATOR &~? (
@@ -862,7 +961,8 @@ CREATE FUNCTION pgroonga_similar_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
-	COST 300;
+	PARALLEL SAFE
+	COST 10000;
 
 -- Deprecated since 1.2.2.
 CREATE OPERATOR &~? (
@@ -887,6 +987,7 @@ CREATE FUNCTION pgroonga_prefix_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^ (
@@ -903,6 +1004,7 @@ CREATE FUNCTION pgroonga_prefix_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^ (
@@ -928,6 +1030,7 @@ CREATE FUNCTION pgroonga_prefix_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^ (
@@ -944,6 +1047,7 @@ CREATE FUNCTION pgroonga_prefix_varchar_array(varchar[], varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^ (
@@ -969,6 +1073,7 @@ CREATE FUNCTION pgroonga_prefix_rk_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~ (
@@ -985,6 +1090,7 @@ CREATE FUNCTION pgroonga_prefix_rk_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~ (
@@ -1010,6 +1116,7 @@ CREATE FUNCTION pgroonga_prefix_rk_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~ (
@@ -1026,6 +1133,7 @@ CREATE FUNCTION pgroonga_prefix_rk_varchar_array(varchar[], varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~ (
@@ -1051,6 +1159,7 @@ CREATE FUNCTION pgroonga_script_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &` (
@@ -1067,6 +1176,7 @@ CREATE FUNCTION pgroonga_script_text_array(text[], text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &` (
@@ -1083,6 +1193,7 @@ CREATE FUNCTION pgroonga_script_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &` (
@@ -1099,6 +1210,7 @@ CREATE FUNCTION pgroonga_script_jsonb(jsonb, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &` (
@@ -1115,6 +1227,7 @@ CREATE FUNCTION pgroonga_match_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 /* Deprecated since 1.2.1. */
@@ -1140,6 +1253,7 @@ CREATE FUNCTION pgroonga_match_in_text_array(text[], text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@| (
@@ -1156,6 +1270,7 @@ CREATE FUNCTION pgroonga_match_in_varchar(varchar, varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &@| (
@@ -1172,6 +1287,7 @@ CREATE FUNCTION pgroonga_query_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 /* Deprecated since 1.2.1. */
@@ -1206,6 +1322,7 @@ CREATE FUNCTION pgroonga_query_in_text_array(text[], text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -1231,6 +1348,7 @@ CREATE FUNCTION pgroonga_query_in_varchar(varchar, varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 -- Deprecated since 1.2.2.
@@ -1256,6 +1374,7 @@ CREATE FUNCTION pgroonga_prefix_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^| (
@@ -1272,6 +1391,7 @@ CREATE FUNCTION pgroonga_not_prefix_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR !&^| (
@@ -1289,6 +1409,7 @@ CREATE FUNCTION pgroonga_prefix_in_text_array(text[], text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^| (
@@ -1305,6 +1426,7 @@ CREATE FUNCTION pgroonga_prefix_in_varchar(varchar, varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^| (
@@ -1321,6 +1443,7 @@ CREATE FUNCTION pgroonga_prefix_in_varchar_array(varchar[], varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^| (
@@ -1337,6 +1460,7 @@ CREATE FUNCTION pgroonga_prefix_rk_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~| (
@@ -1353,6 +1477,7 @@ CREATE FUNCTION pgroonga_prefix_rk_in_text_array(text[], text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~| (
@@ -1369,6 +1494,7 @@ CREATE FUNCTION pgroonga_prefix_rk_in_varchar(varchar, varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~| (
@@ -1385,6 +1511,7 @@ CREATE FUNCTION pgroonga_prefix_rk_in_varchar_array(varchar[], varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &^~| (
@@ -1401,6 +1528,7 @@ CREATE FUNCTION pgroonga_regexp_text(text, text)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &~ (
@@ -1417,6 +1545,7 @@ CREATE FUNCTION pgroonga_regexp_varchar(varchar, varchar)
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &~ (
@@ -1433,6 +1562,7 @@ CREATE FUNCTION pgroonga_regexp_in_text(text, text[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &~| (
@@ -1449,6 +1579,7 @@ CREATE FUNCTION pgroonga_regexp_in_varchar(varchar, varchar[])
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
+	PARALLEL SAFE
 	COST 300;
 
 CREATE OPERATOR &~| (
@@ -1579,7 +1710,8 @@ CREATE FUNCTION pgroonga_match_script_jsonb(jsonb, text)
 	AS 'MODULE_PATHNAME', 'pgroonga_match_script_jsonb'
 	LANGUAGE C
 	IMMUTABLE
-	STRICT;
+	STRICT
+	PARALLEL SAFE;
 
 CREATE OPERATOR @@ (
 	PROCEDURE = pgroonga_match_script_jsonb,
@@ -1772,28 +1904,32 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_score'
 			LANGUAGE C
 			VOLATILE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.table_name(indexName cstring)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_table_name'
 			LANGUAGE C
 			STABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.command(groongaCommand text)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_command'
 			LANGUAGE C
 			VOLATILE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.command(groongaCommand text, arguments text[])
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_command'
 			LANGUAGE C
 			VOLATILE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.query_expand(tableName cstring,
 						      termColumnName text,
@@ -1803,133 +1939,152 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_expand'
 			LANGUAGE C
 			STABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.snippet_html(target text, keywords text[])
 			RETURNS text[]
 			AS 'MODULE_PATHNAME', 'pgroonga_snippet_html'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.highlight_html(target text, keywords text[])
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_highlight_html'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_positions_byte(target text, keywords text[])
 			RETURNS integer[2][]
 			AS 'MODULE_PATHNAME', 'pgroonga_match_positions_byte'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_positions_character(target text, keywords text[])
 			RETURNS integer[2][]
 			AS 'MODULE_PATHNAME', 'pgroonga_match_positions_character'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.query_extract_keywords(query text)
 			RETURNS text[]
 			AS 'MODULE_PATHNAME', 'pgroonga_query_extract_keywords'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.flush(indexName cstring)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_flush'
 			LANGUAGE C
 			VOLATILE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.command_escape_value(value text)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_command_escape_value'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.query_escape(query text)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_query_escape'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value text)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_string'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value text, special_characters text)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_string'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value boolean)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_boolean'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value int2)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_int2'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value int4)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_int4'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value int8)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_int8'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value float4)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_float8'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value float8)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_float8'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value timestamp)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_timestamptz'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.escape(value timestamptz)
 			RETURNS text
 			AS 'MODULE_PATHNAME', 'pgroonga_escape_timestamptz'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 
 		/* v1 */
@@ -1938,28 +2093,32 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_term_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_term(target text[], term text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_term_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_term(target varchar, term varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_term_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_term(target varchar[], term varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_term_varchar_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.%% (
@@ -2000,21 +2159,24 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_query_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_query(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_query_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_query(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_query_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.@@ (
@@ -2047,14 +2209,16 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_regexp_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		CREATE FUNCTION pgroonga.match_regexp(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_regexp_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.@~ (
@@ -2080,7 +2244,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@ (
@@ -2097,7 +2262,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@ (
@@ -2114,7 +2280,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@ (
@@ -2131,7 +2298,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_contain_varchar_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&> (
@@ -2148,7 +2316,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_jsonb'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@ (
@@ -2165,7 +2334,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2191,7 +2361,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2217,7 +2388,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2243,7 +2415,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_jsonb'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2269,7 +2442,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2295,7 +2469,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2321,7 +2496,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2347,7 +2523,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^ (
@@ -2364,7 +2541,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^ (
@@ -2390,7 +2568,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^~ (
@@ -2407,7 +2586,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^~ (
@@ -2433,7 +2613,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_script_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&` (
@@ -2450,7 +2631,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_script_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&` (
@@ -2467,7 +2649,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_script_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&` (
@@ -2484,7 +2667,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_script_jsonb'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&` (
@@ -2501,7 +2685,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			/* Deprecated since 1.2.1. */
@@ -2527,7 +2712,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@| (
@@ -2544,7 +2730,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&@| (
@@ -2561,7 +2748,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			/* Deprecated since 1.2.1. */
@@ -2596,7 +2784,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2622,7 +2811,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			-- Deprecated since 1.2.2.
@@ -2648,7 +2838,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_in_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^| (
@@ -2665,7 +2856,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_in_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^| (
@@ -2682,7 +2874,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_in_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^~| (
@@ -2699,7 +2892,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_in_text_array'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&^~| (
@@ -2716,7 +2910,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_regexp_text'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&~ (
@@ -2733,7 +2928,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_regexp_varchar'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.&~ (
@@ -2857,7 +3053,8 @@ BEGIN
 			AS 'MODULE_PATHNAME', 'pgroonga_match_script_jsonb'
 			LANGUAGE C
 			IMMUTABLE
-			STRICT;
+			STRICT
+			PARALLEL SAFE;
 
 		IF current_schema() <> 'public' THEN
 			CREATE OPERATOR public.@@ (
