@@ -12,9 +12,6 @@
 #include <catalog/pg_type.h>
 #include <utils/builtins.h>
 #include <utils/lsyscache.h>
-#ifdef PGRN_SUPPORT_JSONB
-#	include <utils/jsonb.h>
-#endif
 
 #include <groonga.h>
 
@@ -22,16 +19,13 @@
 
 #include <string.h>
 
-#ifdef PGRN_SUPPORT_JSONB
-PGRN_FUNCTION_INFO_V1(pgroonga_match_script_jsonb);
+PGDLLEXPORT PG_FUNCTION_INFO_V1(pgroonga_match_script_jsonb);
 
 /* v2 */
-PGRN_FUNCTION_INFO_V1(pgroonga_match_jsonb);
-PGRN_FUNCTION_INFO_V1(pgroonga_query_jsonb);
-PGRN_FUNCTION_INFO_V1(pgroonga_script_jsonb);
-#endif
+PGDLLEXPORT PG_FUNCTION_INFO_V1(pgroonga_match_jsonb);
+PGDLLEXPORT PG_FUNCTION_INFO_V1(pgroonga_query_jsonb);
+PGDLLEXPORT PG_FUNCTION_INFO_V1(pgroonga_script_jsonb);
 
-#ifdef PGRN_SUPPORT_JSONB
 typedef struct
 {
 	grn_obj *pathsTable;
@@ -53,6 +47,7 @@ typedef struct PGrnJSONBInsertData
 	grn_obj *sizeColumn;
 	grn_obj *typeColumn;
 	grn_obj *valueIDs;
+	grn_obj *tokenStack;
 	grn_obj key;
 	grn_obj components;
 	grn_obj valueKey;
@@ -74,6 +69,68 @@ static grn_obj *tmpPathsTable = NULL;
 static grn_obj *tmpTypesTable = NULL;
 static grn_obj *tmpValuesTable = NULL;
 
+const char *
+PGrnJSONBIteratorTokenToString(JsonbIteratorToken token)
+{
+	switch (token)
+	{
+	case WJB_DONE:
+		return "done";
+	case WJB_KEY:
+		return "key";
+	case WJB_VALUE:
+		return "value";
+	case WJB_ELEM:
+		return "element";
+	case WJB_BEGIN_ARRAY:
+		return "begin-array";
+	case WJB_END_ARRAY:
+		return "end-array";
+	case WJB_BEGIN_OBJECT:
+		return "begin-object";
+	case WJB_END_OBJECT:
+		return "end-object";
+	default:
+		return "unknown";
+	}
+}
+
+const char *
+PGrnJSONBValueTypeToString(PGRN_JBV_TYPE type)
+{
+	switch (type)
+	{
+	case jbvNull:
+		return "null";
+	case jbvString:
+		return "string";
+	case jbvNumeric:
+		return "numeric";
+	case jbvBool:
+		return "bool";
+	case jbvArray:
+		return "array";
+	case jbvObject:
+		return "object";
+	case jbvBinary:
+		return "binary";
+#ifdef PGRN_HAVE_JSONB_DATETIME
+	case jbvDatetime:
+		return "datetime";
+#endif
+	default:
+		return "unknown";
+	}
+}
+
+Jsonb *
+PGrnJSONBParse(const char *jsonString)
+{
+	Datum jsonbDatum =
+		DirectFunctionCall1(jsonb_in, CStringGetDatum(jsonString));
+	return DatumGetJsonbP(jsonbDatum);
+}
+
 grn_obj *
 PGrnJSONBLookupValuesTable(Relation index,
 						   unsigned int nthAttribute,
@@ -332,23 +389,6 @@ PGrnJSONGenerateCompletePath(grn_obj *components, grn_obj *path)
 						 path);
 }
 
-static const char *
-PGrnJSONIteratorTokenName(JsonbIteratorToken token)
-{
-	static char *names[] = {
-		"WJB_DONE",
-		"WJB_KEY",
-		"WJB_VALUE",
-		"WJB_ELEM",
-		"WJB_BEGIN_ARRAY",
-		"WJB_END_ARRAY",
-		"WJB_BEGIN_OBJECT",
-		"WJB_END_OBJECT"
-	};
-
-	return names[token];
-}
-
 static void
 PGrnJSONBInsertDataInit(PGrnJSONBInsertData *data)
 {
@@ -465,6 +505,9 @@ PGrnJSONBInsertAddPath(PGrnJSONBInsertData *data,
 						 flags,
 						 &(data->path));
 
+	if (GRN_TEXT_LEN(&(data->path)) == 0)
+		return;
+
 	if (GRN_TEXT_LEN(&(data->path)) >= GRN_TABLE_MAX_KEY_SIZE)
 		return;
 
@@ -662,6 +705,13 @@ PGrnJSONBInsertValue(JsonbIterator **iter,
 		GRN_BOOL_SET(ctx, &(data->value), value->val.boolean);
 		PGrnJSONBInsertValueSet(data, data->booleanColumn, "boolean");
 		break;
+#ifdef PGRN_HAVE_JSONB_DATETIME
+	case jbvDatetime:
+		ereport(ERROR,
+				(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
+				 errmsg("pgroonga: datetime value for jsonb isn't supported")));
+		break;
+#endif
 	case jbvArray:
 		PGrnJSONBInsertContainer(iter, data);
 		break;
@@ -678,12 +728,18 @@ static void
 PGrnJSONBInsertContainer(JsonbIterator **iter, PGrnJSONBInsertData *data)
 {
 	JsonbIteratorToken token;
+	JsonbIteratorToken lastToken = WJB_DONE;
 	JsonbValue value;
 
+	/* Suppress -Wunused-but-set-variable */
+	(void)lastToken;
+
+	GRN_BULK_REWIND(data->tokenStack);
 	while ((token = JsonbIteratorNext(iter, &value, false)) != WJB_DONE) {
 		switch (token)
 		{
 		case WJB_KEY:
+			GRN_UINT8_PUT(ctx, data->tokenStack, token);
 			grn_vector_add_element(ctx, &(data->components),
 								   value.val.string.val,
 								   value.val.string.len,
@@ -691,19 +747,24 @@ PGrnJSONBInsertContainer(JsonbIterator **iter, PGrnJSONBInsertData *data)
 								   GRN_DB_SHORT_TEXT);
 			break;
 		case WJB_VALUE:
+			/* WJB_VALUE isn't emitted when a value is an array or an
+			   object. */
 			PGrnJSONBInsertValue(iter, &value, data);
 			{
 				const char *component;
 				grn_vector_pop_element(ctx, &(data->components), &component,
 									   NULL, NULL);
 			}
+			GRN_UINT8_POP(data->tokenStack, lastToken);
 			break;
 		case WJB_ELEM:
 			PGrnJSONBInsertValue(iter, &value, data);
 			break;
 		case WJB_BEGIN_ARRAY:
 		{
-			uint32_t nElements = value.val.array.nElems;
+			uint32_t nElements;
+			GRN_UINT8_PUT(ctx, data->tokenStack, token);
+			nElements = value.val.array.nElems;
 			grn_vector_add_element(ctx, &(data->components),
 								   (const char *)&nElements,
 								   sizeof(uint32_t),
@@ -715,20 +776,44 @@ PGrnJSONBInsertContainer(JsonbIterator **iter, PGrnJSONBInsertData *data)
 		case WJB_END_ARRAY:
 		{
 			const char *component;
+			size_t nTokens;
 			grn_vector_pop_element(ctx, &(data->components), &component,
 								   NULL, NULL);
+			GRN_UINT8_POP(data->tokenStack, lastToken);
+			nTokens = GRN_UINT8_VECTOR_SIZE(data->tokenStack);
+			if (nTokens > 0 &&
+				GRN_UINT8_VALUE_AT(data->tokenStack, nTokens - 1) == WJB_KEY)
+			{
+				grn_vector_pop_element(ctx, &(data->components), &component,
+									   NULL, NULL);
+				GRN_UINT8_POP(data->tokenStack, lastToken);
+			}
 			break;
 		}
 		case WJB_BEGIN_OBJECT:
+			GRN_UINT8_PUT(ctx, data->tokenStack, token);
 			PGrnJSONBInsertValueSet(data, NULL, "object");
 			break;
 		case WJB_END_OBJECT:
+		{
+			size_t nTokens;
+			GRN_UINT8_POP(data->tokenStack, lastToken);
+			nTokens = GRN_UINT8_VECTOR_SIZE(data->tokenStack);
+			if (nTokens > 0 &&
+				GRN_UINT8_VALUE_AT(data->tokenStack, nTokens - 1) == WJB_KEY)
+			{
+				const char *component;
+				grn_vector_pop_element(ctx, &(data->components), &component,
+									   NULL, NULL);
+				GRN_UINT8_POP(data->tokenStack, lastToken);
+			}
 			break;
+		}
 		default:
 			ereport(ERROR,
 					(errcode(ERRCODE_SYSTEM_ERROR),
-					 errmsg("pgroonga: jsonb iterator returns invalid token: %d",
-							token)));
+					 errmsg("pgroonga: jsonb iterator returns invalid token: %s",
+							PGrnJSONBIteratorTokenToString(token))));
 			break;
 		}
 	}
@@ -757,6 +842,9 @@ PGrnJSONBInsertValueForFullTextSearch(JsonbIterator **iter,
 		break;
 	case jbvNumeric:
 	case jbvBool:
+#ifdef PGRN_HAVE_JSONB_DATETIME
+	case jbvDatetime:
+#endif
 		break;
 	case jbvArray:
 		PGrnJSONBInsertContainerForFullTextSearch(iter, data);
@@ -794,18 +882,16 @@ PGrnJSONBInsertContainerForFullTextSearch(JsonbIterator **iter,
 		default:
 			ereport(ERROR,
 					(errcode(ERRCODE_SYSTEM_ERROR),
-					 errmsg("pgroonga: jsonb iterator returns invalid token: %d",
-							token)));
+					 errmsg("pgroonga: jsonb iterator returns invalid token: %s",
+							PGrnJSONBIteratorTokenToString(token))));
 			break;
 		}
 	}
 }
-#endif
 
 void
 PGrnInitializeJSONB(void)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	PGrnJSONBCreateData data;
 
 	tmpPathsTable = PGrnJSONBCreatePathsTable(InvalidRelation, NULL);
@@ -816,20 +902,16 @@ PGrnInitializeJSONB(void)
 	data.typesTable = tmpTypesTable;
 	data.valuesTable = tmpValuesTable;
 	PGrnJSONBCreateDataColumns(InvalidRelation, &data);
-#endif
 }
 
 void
 PGrnFinalizeJSONB(void)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	grn_obj_remove(ctx, tmpValuesTable);
 	grn_obj_remove(ctx, tmpTypesTable);
 	grn_obj_remove(ctx, tmpPathsTable);
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnJSONBCreateTables(PGrnCreateData *data,
 					  PGrnJSONBCreateData *jsonbData)
@@ -874,16 +956,18 @@ PGrnJSONBCreateFullTextSearchIndexColumn(PGrnCreateData *data,
 	grn_obj *type;
 	grn_obj *lexicon;
 	grn_obj *tokenizer = NULL;
-	grn_obj *normalizer = NULL;
-	grn_obj *tokenFilters = &(buffers->tokenFilters);
+	grn_obj *normalizers = NULL;
+	grn_obj *tokenFilters = NULL;
+	grn_column_flags indexFlags = GRN_OBJ_COLUMN_INDEX | GRN_OBJ_WITH_POSITION;
 
-	GRN_BULK_REWIND(tokenFilters);
 	PGrnApplyOptionValues(data->index,
+						  data->i,
 						  PGRN_OPTION_USE_CASE_FULL_TEXT_SEARCH,
 						  &tokenizer, PGRN_DEFAULT_TOKENIZER,
-						  &normalizer, PGRN_DEFAULT_NORMALIZER,
-						  tokenFilters,
-						  &flags);
+						  &normalizers, PGRN_DEFAULT_NORMALIZERS,
+						  &tokenFilters,
+						  &flags,
+						  &indexFlags);
 
 	if (!tokenizer)
 		return;
@@ -897,7 +981,7 @@ PGrnJSONBCreateFullTextSearchIndexColumn(PGrnCreateData *data,
 							  flags,
 							  type,
 							  tokenizer,
-							  normalizer,
+							  normalizers,
 							  tokenFilters);
 	GRN_PTR_PUT(ctx, data->lexicons, lexicon);
 
@@ -975,19 +1059,13 @@ PGrnJSONBCreateIndexColumns(PGrnCreateData *data,
 
 	PGrnJSONBCreateFullTextSearchIndexColumn(data, jsonbData);
 }
-#endif
 
 bool
 PGrnAttributeIsJSONB(Oid id)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	return id == JSONBOID;
-#else
-	return false;
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static bool
 PGrnJSONBIsForFullTextSearchOnly(Relation index, unsigned int nthAttribute)
 {
@@ -1000,12 +1078,10 @@ PGrnJSONBIsForFullTextSearchOnly(Relation index, unsigned int nthAttribute)
 	return !OidIsValid(strategyOID);
 
 }
-#endif
 
 void
 PGrnJSONBCreate(PGrnCreateData *data)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	if (data->desc->natts != 1)
 	{
 		ereport(ERROR,
@@ -1034,10 +1110,8 @@ PGrnJSONBCreate(PGrnCreateData *data)
 		data->attributeFlags = GRN_OBJ_VECTOR;
 		PGrnCreateDataColumn(data);
 	}
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnJSONBValueSetSource(Relation index,
 						grn_obj *jsonValuesTable,
@@ -1117,12 +1191,10 @@ PGrnJSONBSetSources(Relation index,
 
 	grn_obj_unlink(ctx, jsonPathsTable);
 }
-#endif
 
 grn_obj *
 PGrnJSONBSetSource(Relation index, unsigned int i)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	grn_obj *indexColumn;
 
 	if (PGrnJSONBIsForFullTextSearchOnly(index, i))
@@ -1140,12 +1212,8 @@ PGrnJSONBSetSource(Relation index, unsigned int i)
 	}
 
 	return indexColumn;
-#else
-	return NULL;
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnJSONBDeleteValues(grn_obj *valuesTable, grn_obj *valueIDs)
 {
@@ -1171,6 +1239,7 @@ PGrnJSONBMatchExpression(Jsonb *target,
 						 const char *logTag)
 {
 	grn_obj valueIDs;
+	grn_obj tokenStack;
 	PGrnJSONBInsertData data;
 	JsonbIterator *iter;
 	grn_obj *matchTarget = NULL;
@@ -1188,6 +1257,8 @@ PGrnJSONBMatchExpression(Jsonb *target,
 	data.valuesTable = tmpValuesTable;
 	GRN_PTR_INIT(&valueIDs, GRN_OBJ_VECTOR, grn_obj_id(ctx, data.valuesTable));
 	data.valueIDs = &valueIDs;
+	GRN_UINT8_INIT(&tokenStack, GRN_OBJ_VECTOR);
+	data.tokenStack = &tokenStack;
 	PGrnJSONBInsertDataInit(&data);
 	iter = JsonbIteratorInit(&(target->root));
 	PGrnJSONBInsertContainer(&iter, &data);
@@ -1270,6 +1341,7 @@ PGrnJSONBMatchExpression(Jsonb *target,
 			grn_obj_close(ctx, condition);
 		if (matchTarget)
 			grn_obj_close(ctx, matchTarget);
+		GRN_OBJ_FIN(ctx, &tokenStack);
 		PGrnJSONBDeleteValues(tmpValuesTable, &valueIDs);
 		GRN_OBJ_FIN(ctx, &valueIDs);
 		PG_RE_THROW();
@@ -1295,7 +1367,7 @@ PGrnJSONBMatchExpression(Jsonb *target,
 Datum
 pgroonga_match_script_jsonb(PG_FUNCTION_ARGS)
 {
-	Jsonb *target = PG_GETARG_JSONB(0);
+	Jsonb *target = PG_GETARG_JSONB_P(0);
 	text *script = PG_GETARG_TEXT_PP(1);
 	bool matched;
 
@@ -1314,7 +1386,7 @@ pgroonga_match_script_jsonb(PG_FUNCTION_ARGS)
 Datum
 pgroonga_match_jsonb(PG_FUNCTION_ARGS)
 {
-	Jsonb *target = PG_GETARG_JSONB(0);
+	Jsonb *target = PG_GETARG_JSONB_P(0);
 	text *term = PG_GETARG_TEXT_PP(1);
 	bool matched;
 
@@ -1333,7 +1405,7 @@ pgroonga_match_jsonb(PG_FUNCTION_ARGS)
 Datum
 pgroonga_query_jsonb(PG_FUNCTION_ARGS)
 {
-	Jsonb *target = PG_GETARG_JSONB(0);
+	Jsonb *target = PG_GETARG_JSONB_P(0);
 	text *query = PG_GETARG_TEXT_PP(1);
 	bool matched;
 
@@ -1352,7 +1424,7 @@ pgroonga_query_jsonb(PG_FUNCTION_ARGS)
 Datum
 pgroonga_script_jsonb(PG_FUNCTION_ARGS)
 {
-	Jsonb *target = PG_GETARG_JSONB(0);
+	Jsonb *target = PG_GETARG_JSONB_P(0);
 	text *script = PG_GETARG_TEXT_PP(1);
 	bool matched;
 
@@ -1413,7 +1485,7 @@ PGrnJSONBInsertRecord(Relation index,
 							sizeof(uint64));
 	}
 
-	attribute = desc->attrs[0];
+	attribute = TupleDescAttr(desc, 0);
 	attributeName = &(attribute->attname);
 	column = PGrnLookupColumn(sourcesTable, attributeName->data, ERROR);
 	if (data->isForFullTextSearchOnly)
@@ -1455,7 +1527,6 @@ PGrnJSONBInsertRecord(Relation index,
 	PGrnWALInsertFinish(walData);
 	PGrnWALFinish(walData);
 }
-#endif
 
 uint32_t
 PGrnJSONBInsert(Relation index,
@@ -1466,13 +1537,8 @@ PGrnJSONBInsert(Relation index,
 				uint64_t packedCtid)
 {
 	uint32_t recordSize = 0; /* always 0 */
-#ifdef PGRN_SUPPORT_JSONB
 	PGrnJSONBInsertData data;
 	unsigned int nthAttribute = 0;
-	Jsonb *jsonb;
-
-	if (isnull[nthAttribute])
-		return recordSize;
 
 	data.index = index;
 	data.isForFullTextSearchOnly =
@@ -1485,11 +1551,15 @@ PGrnJSONBInsert(Relation index,
 		grn_obj_reinit(ctx, data.valueIDs,
 					   grn_obj_id(ctx, data.valuesTable),
 					   GRN_OBJ_VECTOR);
+		data.tokenStack = &(buffers->jsonbTokenStack);
 	}
 	PGrnJSONBInsertDataInit(&data);
 
-	jsonb = DatumGetJsonb(values[nthAttribute]);
-	PGrnJSONBInsertJSONB(&data, jsonb);
+	if (!isnull[nthAttribute])
+	{
+		Jsonb *jsonb = DatumGetJsonbP(values[nthAttribute]);
+		PGrnJSONBInsertJSONB(&data, jsonb);
+	}
 
 	PGrnJSONBInsertRecord(index,
 						  sourcesTable,
@@ -1498,12 +1568,10 @@ PGrnJSONBInsert(Relation index,
 						  &data);
 
 	PGrnJSONBInsertDataFin(&data);
-#endif
 
 	return recordSize;
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnSearchBuildConditionJSONScript(PGrnSearchData *data,
 								   grn_obj *subFilter,
@@ -1736,14 +1804,13 @@ PGrnSearchBuildConditionJSONContain(PGrnSearchData *data,
 		default:
 			ereport(ERROR,
 					(errcode(ERRCODE_SYSTEM_ERROR),
-					 errmsg("pgroonga: jsonb iterator returns invalid token: %d",
-							token)));
+					 errmsg("pgroonga: jsonb iterator returns invalid token: %s",
+							PGrnJSONBIteratorTokenToString(token))));
 			break;
 		}
 	}
 	GRN_OBJ_FIN(ctx, &components);
 }
-#endif
 
 bool
 PGrnJSONBBuildSearchCondition(PGrnSearchData *data,
@@ -1751,7 +1818,6 @@ PGrnJSONBBuildSearchCondition(PGrnSearchData *data,
 							  ScanKey key,
 							  grn_obj *targetColumn)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	unsigned int nthAttribute = 0;
 	grn_obj *subFilter;
 
@@ -1809,11 +1875,11 @@ PGrnJSONBBuildSearchCondition(PGrnSearchData *data,
 											  &(buffers->keyword));
 		}
 		break;
-	case PGrnJSONContainStrategyNumber:
+	case PGrnContainStrategyNumber:
 		PGrnSearchBuildConditionJSONContain(data,
 											subFilter,
 											targetColumn,
-											DatumGetJsonb(key->sk_argument));
+											DatumGetJsonbP(key->sk_argument));
 		break;
 	default:
 		ereport(ERROR,
@@ -1823,12 +1889,8 @@ PGrnJSONBBuildSearchCondition(PGrnSearchData *data,
 		break;
 	}
 	return true;
-#else
-	return false;
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnJSONValuesUpdateDeletedID(grn_obj *jsonValuesTable,
 							  grn_obj *values,
@@ -1921,12 +1983,10 @@ PGrnJSONValuesDeleteBulk(PGrnJSONBBulkDeleteData *data)
 
 	grn_table_cursor_close(ctx, tableCursor);
 }
-#endif
 
 void
 PGrnJSONBBulkDeleteInit(PGrnJSONBBulkDeleteData *data)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	Relation index = data->index;
 	unsigned int nthAttribute = 0;
 	TupleDesc desc;
@@ -1934,7 +1994,7 @@ PGrnJSONBBulkDeleteInit(PGrnJSONBBulkDeleteData *data)
 	grn_id valuesTableID;
 
 	desc = RelationGetDescr(index);
-	attribute = desc->attrs[nthAttribute];
+	attribute = TupleDescAttr(desc, nthAttribute);
 	data->isJSONBAttribute = PGrnAttributeIsJSONB(attribute->atttypid);
 	if (!data->isJSONBAttribute)
 		return;
@@ -1959,13 +2019,11 @@ PGrnJSONBBulkDeleteInit(PGrnJSONBBulkDeleteData *data)
 
 	GRN_RECORD_SET(ctx, &(data->valueMin), GRN_ID_NIL);
 	GRN_RECORD_SET(ctx, &(data->valueMax), GRN_ID_NIL);
-#endif
 }
 
 void
 PGrnJSONBBulkDeleteRecord(PGrnJSONBBulkDeleteData *data)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	if (!data->isJSONBAttribute)
 		return;
 
@@ -1981,13 +2039,11 @@ PGrnJSONBBulkDeleteRecord(PGrnJSONBBulkDeleteData *data)
 								  &(data->values),
 								  &(data->valueMin),
 								  &(data->valueMax));
-#endif
 }
 
 void
 PGrnJSONBBulkDeleteFin(PGrnJSONBBulkDeleteData *data)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	if (!data->isJSONBAttribute)
 		return;
 
@@ -2000,10 +2056,8 @@ PGrnJSONBBulkDeleteFin(PGrnJSONBBulkDeleteData *data)
 	grn_obj_unlink(ctx, data->sourcesValuesColumn);
 	grn_obj_unlink(ctx, data->valuesIndexColumn);
 	grn_obj_unlink(ctx, data->valuesTable);
-#endif
 }
 
-#ifdef PGRN_SUPPORT_JSONB
 static void
 PGrnRemoveJSONValueLexicon(const char *typeName, unsigned int relationID)
 {
@@ -2015,12 +2069,10 @@ PGrnRemoveJSONValueLexicon(const char *typeName, unsigned int relationID)
 		return;
 	PGrnRemoveObject(tableName);
 }
-#endif
 
 void
 PGrnJSONBRemoveUnusedTables(Oid relationFileNodeID)
 {
-#ifdef PGRN_SUPPORT_JSONB
 	{
 		char jsonValuesTableName[GRN_TABLE_MAX_KEY_SIZE];
 		snprintf(jsonValuesTableName, sizeof(jsonValuesTableName),
@@ -2030,34 +2082,33 @@ PGrnJSONBRemoveUnusedTables(Oid relationFileNodeID)
 			return;
 	}
 
-		PGrnRemoveJSONValueLexicon("FullTextSearch", relationFileNodeID);
-		PGrnRemoveJSONValueLexicon("String", relationFileNodeID);
-		PGrnRemoveJSONValueLexicon("Number", relationFileNodeID);
-		PGrnRemoveJSONValueLexicon("Boolean", relationFileNodeID);
-		PGrnRemoveJSONValueLexicon("Size", relationFileNodeID);
+	PGrnRemoveJSONValueLexicon("FullTextSearch", relationFileNodeID);
+	PGrnRemoveJSONValueLexicon("String", relationFileNodeID);
+	PGrnRemoveJSONValueLexicon("Number", relationFileNodeID);
+	PGrnRemoveJSONValueLexicon("Boolean", relationFileNodeID);
+	PGrnRemoveJSONValueLexicon("Size", relationFileNodeID);
 
-		{
-			char name[GRN_TABLE_MAX_KEY_SIZE];
+	{
+		char name[GRN_TABLE_MAX_KEY_SIZE];
 
-			snprintf(name, sizeof(name),
-					 PGrnJSONPathsTableNameFormat ".%s",
-					 relationFileNodeID, 0, PGrnIndexColumnName);
-			PGrnRemoveObject(name);
+		snprintf(name, sizeof(name),
+				 PGrnJSONPathsTableNameFormat ".%s",
+				 relationFileNodeID, 0, PGrnIndexColumnName);
+		PGrnRemoveObject(name);
 
-			snprintf(name, sizeof(name),
-					 PGrnJSONValuesTableNameFormat,
-					 relationFileNodeID, 0);
-			PGrnRemoveObject(name);
+		snprintf(name, sizeof(name),
+				 PGrnJSONValuesTableNameFormat,
+				 relationFileNodeID, 0);
+		PGrnRemoveObject(name);
 
-			snprintf(name, sizeof(name),
-					 PGrnJSONPathsTableNameFormat,
-					 relationFileNodeID, 0);
-			PGrnRemoveObject(name);
+		snprintf(name, sizeof(name),
+				 PGrnJSONPathsTableNameFormat,
+				 relationFileNodeID, 0);
+		PGrnRemoveObject(name);
 
-			snprintf(name, sizeof(name),
-					 PGrnJSONTypesTableNameFormat,
-					 relationFileNodeID, 0);
-			PGrnRemoveObject(name);
-		}
-#endif
+		snprintf(name, sizeof(name),
+				 PGrnJSONTypesTableNameFormat,
+				 relationFileNodeID, 0);
+		PGrnRemoveObject(name);
+	}
 }
